# DataCenterCommitmentInterval

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**time** | **datetime** |  | [optional] 
**vcpus** | **float** |  | [optional] 
**vcpu_revenue_usd** | [**Decimal**](Decimal.md) |  | [optional] 
**gpus** | **float** |  | [optional] 
**gpu_revenue_usd** | [**Decimal**](Decimal.md) |  | [optional] 
**memory_gib** | **float** |  | [optional] 
**memory_revenue_usd** | [**Decimal**](Decimal.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


